==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ro.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacte",
    "All contacts" : "Toate contactele",
    "Details" : "Detalii",
    "Loading" : "Loading",
    "Name" : "Nume",
    "Title" : "Titlu",
    "Download" : "Descărcare",
    "Delete" : "Șterge",
    "Groups" : "Grupuri",
    "New contact" : "Contact nou ",
    "No results" : "Niciun rezultat",
    "Rename" : "Redenumește",
    "Enabled" : "Activat",
    "Disabled" : "Dezactivat",
    "Copy link" : "Copiază linkul",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "can edit" : "poate edita",
    "Importing into" : "Se importă în",
    "Import into" : "Importă în",
    "Address book name" : "Numele listă de contacte",
    "First name" : "Prenume",
    "Last name" : "Nume",
    "Display name" : "Nume afișat",
    "Not grouped" : "Negrupate",
    "Nickname" : "Pseudonim",
    "Detailed name" : "Nume detaliat",
    "Additional names" : "Nume adiționale",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "Notes" : "Notă",
    "Website" : "Website",
    "Location" : "Locație",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Acasă",
    "Work" : "Serviciu",
    "Other" : "Altele",
    "Address" : "Adresă",
    "Post office box" : "Oficiul poștal",
    "City" : "Oraș",
    "State or province" : "Județ sau provincie",
    "Postal code" : "Codul poștal",
    "Country" : "Țară",
    "Birthday" : "Zi de naștere",
    "Anniversary" : "Aniversare",
    "Date of death" : "Data decesului",
    "Email" : "Email",
    "Instant messaging" : "Mesagerie instantă",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Telefon serviciu",
    "Fax" : "Fax",
    "Fax home" : "Fax - acasă",
    "Fax work" : "Fax - serviciu",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Car" : "Mașina",
    "Work pager" : "Pager de serviciu",
    "Social network" : "Rețea socială",
    "Relationship" : "Legătură",
    "Spouse" : "Soție",
    "Child" : "Copil",
    "Mother" : "Mamă",
    "Father" : "Tată",
    "Parent" : "Părinte",
    "Brother" : "Frate",
    "Sister" : "Soră",
    "Relative" : "Rudă",
    "Friend" : "Prieten",
    "Colleague" : "Coleg",
    "Manager" : "Director",
    "Assistant" : "Asistent",
    "Contact" : "Contact",
    "Gender" : "Sex",
    "Female" : "Femeie",
    "Male" : "Bărbat",
    "None" : "Niciuna",
    "Unknown" : "Necunoscut"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-contacts-3.3.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ro.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacte",
    "All contacts" : "Toate contactele",
    "Details" : "Detalii",
    "Invalid image" : "Imagine invalidă",
    "Loading" : "Loading",
    "Name" : "Nume",
    "Title" : "Titlu",
    "Download" : "Descărcare",
    "Delete" : "Șterge",
    "Cancel" : "Anulează",
    "Address book" : "Listă de contacte",
    "Groups" : "Grupuri",
    "New contact" : "Contact nou ",
    "No results" : "Niciun rezultat",
    "Rename" : "Redenumește",
    "Enabled" : "Activat",
    "Disabled" : "Dezactivat",
    "Copy link" : "Copiază linkul",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "can edit" : "poate edita",
    "Address book name" : "Numele listă de contacte",
    "First name" : "Prenume",
    "Last name" : "Nume",
    "Display name" : "Nume afișat",
    "Not grouped" : "Negrupate",
    "Nickname" : "Pseudonim",
    "Detailed name" : "Nume detaliat",
    "Additional names" : "Nume adiționale",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "Notes" : "Notă",
    "Website" : "Website",
    "Location" : "Locație",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Acasă",
    "Work" : "Serviciu",
    "Other" : "Altele",
    "Address" : "Adresă",
    "Post office box" : "Oficiul poștal",
    "City" : "Oraș",
    "State or province" : "Județ sau provincie",
    "Postal code" : "Codul poștal",
    "Country" : "Țară",
    "Birthday" : "Zi de naștere",
    "Anniversary" : "Aniversare",
    "Date of death" : "Data decesului",
    "Email" : "Email",
    "Instant messaging" : "Mesagerie instantă",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Telefon serviciu",
    "Fax" : "Fax",
    "Fax home" : "Fax - acasă",
    "Fax work" : "Fax - serviciu",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Car" : "Mașina",
    "Work pager" : "Pager de serviciu",
    "Social network" : "Rețea socială",
    "Relationship" : "Legătură",
    "Spouse" : "Soție",
    "Child" : "Copil",
    "Mother" : "Mamă",
    "Father" : "Tată",
    "Parent" : "Părinte",
    "Brother" : "Frate",
    "Sister" : "Soră",
    "Relative" : "Rudă",
    "Friend" : "Prieten",
    "Colleague" : "Coleg",
    "Manager" : "Director",
    "Assistant" : "Asistent",
    "Contact" : "Contact",
    "Gender" : "Sex",
    "Female" : "Femeie",
    "Male" : "Bărbat",
    "None" : "Niciuna",
    "Unknown" : "Necunoscut"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
